/*
  (C) 2005 Jack Lloyd <lloyd@randombit.net>
*/

#ifndef __cplusplus
  #error You cannot include this header except in C++
#endif

#ifndef CUTLASS_FILTERS_H__
#define CUTLASS_FILTERS_H__

#include <botan/pipe.h>
#include <botan/basefilt.h>
using namespace Botan;

class Cutlass_Kex_Writer : public Filter
   {
   public:
      void start_msg();
      void end_msg();
      void write(const byte[], u32bit);
   private:
      SecureVector<byte> msg_buf;
   };

class Cutlass_Kex_Reader : public Filter
   {
   public:
      void start_msg();
      void end_msg();
      void write(const byte[], u32bit);
   private:
      SecureVector<byte> msg_buf;
   };

class Cutlass_Encryptor : public Filter
   {
   public:
      void start_msg();
      void end_msg();
      void write(const byte[], u32bit);

      Cutlass_Encryptor(const std::string&, const std::string&,
                        const SymmetricKey&, const SymmetricKey&, u32bit);
   private:
      Pipe crypto_layer;
      Keyed_Filter* cipher;
      Keyed_Filter* mac;
      u32bit seq_no, iv_len, mtu;
      SecureVector<byte> msg_buf;
   };

class Cutlass_Decryptor : public Filter
   {
   public:
      void start_msg();
      void end_msg();
      void write(const byte[], u32bit);

      Cutlass_Decryptor(const std::string&, const std::string&,
                        const SymmetricKey&, const SymmetricKey&);
   private:
      Pipe crypto_layer;
      Keyed_Filter* cipher;
      Keyed_Filter* mac;
      u32bit iv_len, mac_len;
      SecureVector<byte> msg_buf;
      std::vector<u32bit> window;
   };

#endif
