/*
 * handshake.h
 *
 * Function declarations for handshake.c
 *
 * Copyright (c) 2004 Todd MacDermid <tmacd@synacklabs.net>
 *                    Jack Lloyd <lloyd@randombit.net>
 *
 */

#ifndef HANDSHAKE_H
#define HANDSHAKE_H

#include <cutlass/crypto.h>

#ifdef __cplusplus
extern "C" {
#endif

/* Old handshake goo */
int
cutlass_kex_respond(cutlass_t *cut_handle, conn_t *conn, 
                   uint8_t *payload, struct cutlass_packet_hdr *in_header, 
                   struct timespec *now);

int
cutlass_kex_init(cutlass_t *cut_handle, conn_t *conn, struct timespec *now);


/* New handshake goo */

/* Send a client hello. That is all this function does. NOTHING MORE. */
int cutlass_handshake_init(cutlass_t *cut_handle, conn_t *conn,
                           cutlass_public_key peer_key,
                           cutlass_private_key local_key);

int cutlass_handshake_init_no_server(cutlass_t *cut_handle, conn_t *conn,
                                     cutlass_private_key local_key);

/* Recieve some handshake data, and make a response, if needed.
   If in and in_header are both NULL, then retransmit last message sent

   Return 0 == OK
          1 == Something bad, abort handshake
*/

int cutlass_process_handshake(cutlass_t *cut_handle, conn_t *conn,
                              const uint8_t* in,
                              struct cutlass_packet_hdr *in_header,
                              struct timespec *now);

int
cutlass_conn_activate(cutlass_t *cut_handle, conn_t *conn, 
                      struct timespec *now);

void
user_conn_action(cutlass_t *cut_handle, conn_t *conn);

#ifdef __cplusplus
}
#endif

#endif /* HANDSHAKE_H */
