
/*
 * table_control.h
 *
 * Function declarations for table_control.c
 * These functions should be the ONLY ones locking the hashtable-protecting
 * mutex!
 *
 * Copyright (c) 2004 Todd MacDermid <tmacd@synacklabs.net>
 *
 */

#ifndef TABLE_CONTROL_H
#define TABLE_CONTROL_H

#ifdef __cplusplus
extern "C" {
#endif

int hashtable_fd_add(cutlass_t *, conn_t *);
int hashtable_addr_add(cutlass_t *, conn_t *);
int hashtable_fingerprint_add(cutlass_t *cut_handle, conn_t *conn, uint8_t *);

conn_t *hashtable_fd_find(cutlass_t *, int);
conn_t *hashtable_addr_find(cutlass_t *, struct sockaddr_in *);
conn_t *hashtable_fingerprint_find(cutlass_t *, uint8_t *);

int hashtable_fd_del(cutlass_t *, int);
int hashtable_addr_del(cutlass_t *, struct sockaddr_in  *);
int hashtable_conn_del(cutlass_t *, conn_t *);
int hashtable_fingerprint_del(cutlass_t *cut_handle, uint8_t *fingerprint);

int hashtable_group_add(cutlass_t *cut_handle, group_t *group);
group_t * hashtable_group_find(cutlass_t *cut_handle, uint8_t *group_id);
int hashtable_group_del(cutlass_t *cut_handle, uint8_t *group_id);

conn_t *cutlass_addr_find(cutlass_t *cut_handle, struct sockaddr_in *addr);
int cutlass_conn_release(cutlass_t *cut_handle, conn_t *conn);

int internal_conn_list(cutlass_t *, conn_t **, int);
int cutlass_conn_list(cutlass_t *, uint8_t *, int);
int 
release_conn_list(cutlass_t *cut_handle, conn_t **conn_array, int num_conn);

#ifdef __cplusplus
}
#endif

#endif /* TABLE_CONTROL_H */
